==> televerse-1.10.2.tar.gz: lib/src/telegram/models/login_url.dart <==
part of models;

/// This object represents a parameter of the inline keyboard button used to automatically authorize a user. Serves as a great replacement for the Telegram Login Widget when the user is coming from Telegram. All the user needs to do is tap/click a button and confirm that they want to log in:
///
/// Telegram apps support these buttons as of version 5.7.
///
/// Sample bot: @discussbot
class LoginURL {
  /// An HTTP URL to be opened with user authorization data added to the query string when the button is pressed. If the user refuses to provide authorization data, the original URL without information about the user will be opened. The data added is the same as described in Receiving authorization data.
  ///
  /// NOTE: You must always check the hash of the received data to verify the authentication and the integrity of the data as described in Checking authorization.
  String url;

  /// Optional. New text of the button in forwarded messages.
  String? forwardText;

  /// Optional. Username of a bot, which will be used for user authorization. See Setting up a bot for more details. If not specified, the current bot's username will be assumed. The url's domain must be the same as the domain linked with the bot. See Linking your domain to the bot for more details.
  String? botUsername;

  /// Optional. Pass True to request the permission for your bot to send messages to the user.
  bool? requestWriteAccess;

  /// Constructs a [LoginURL] object
  LoginURL({
    required this.url,
    this.forwardText,
    this.botUsername,
    this.requestWriteAccess,
  });

  /// Creates a [LoginURL] object from JSON object
  factory LoginURL.fromJson(Map<String, dynamic> json) {
    return LoginURL(
      url: json['url'],
      forwardText: json['forward_text'],
      botUsername: json['bot_username'],
      requestWriteAccess: json['request_write_access'],
    );
  }

  /// Converts a [LoginURL] object to JSON object
  Map<String, dynamic> toJson() {
    return {
      'url': url,
      'forward_text': forwardText,
      'bot_username': botUsername,
      'request_write_access': requestWriteAccess,
    }..removeWhere((key, value) => value == null);
  }
}

==> televerse-1.15.10.tar.gz: lib/src/telegram/models/login_url.dart <==
part of 'models.dart';

/// This object represents a parameter of the inline keyboard button used to automatically authorize a user. Serves as a great replacement for the Telegram Login Widget when the user is coming from Telegram. All the user needs to do is tap/click a button and confirm that they want to log in:
///
/// Telegram apps support these buttons as of version 5.7.
///
/// Sample bot: @discussbot
class LoginURL {
  /// An HTTP URL to be opened with user authorization data added to the query string when the button is pressed. If the user refuses to provide authorization data, the original URL without information about the user will be opened. The data added is the same as described in Receiving authorization data.
  ///
  /// NOTE: You must always check the hash of the received data to verify the authentication and the integrity of the data as described in Checking authorization.
  final String url;

  /// Optional. New text of the button in forwarded messages.
  final String? forwardText;

  /// Optional. Username of a bot, which will be used for user authorization. See Setting up a bot for more details. If not specified, the current bot's username will be assumed. The url's domain must be the same as the domain linked with the bot. See Linking your domain to the bot for more details.
  final String? botUsername;

  /// Optional. Pass True to request the permission for your bot to send messages to the user.
  final bool? requestWriteAccess;

  /// Constructs a [LoginURL] object
  const LoginURL({
    required this.url,
    this.forwardText,
    this.botUsername,
    this.requestWriteAccess,
  });

  /// Creates a [LoginURL] object from JSON object
  factory LoginURL.fromJson(Map<String, dynamic> json) {
    return LoginURL(
      url: json['url'],
      forwardText: json['forward_text'],
      botUsername: json['bot_username'],
      requestWriteAccess: json['request_write_access'],
    );
  }

  /// Converts a [LoginURL] object to JSON object
  Map<String, dynamic> toJson() {
    return {
      'url': url,
      'forward_text': forwardText,
      'bot_username': botUsername,
      'request_write_access': requestWriteAccess,
    }..removeWhere(_nullFilter);
  }
}
